@@ -1,5 +1,5 @@
 package App::cpanminus;
-our $VERSION = "1.7015";
+our $VERSION = "1.7016";
 
 =encoding utf8
 
@@ -38,7 +38,7 @@ install, and later upgrade.
 
 You can also use the latest cpanminus to install cpanminus itself:
 
-    curl -L http://cpanmin.us | perl - --sudo App::cpanminus
+    curl -L https://cpanmin.us | perl - --sudo App::cpanminus
 
 This will install C<cpanm> to your bin directory like
 C</usr/local/bin> and you'll need the C<--sudo> option to write to
@@ -51,7 +51,7 @@ tools like L<perlbrew>, you don't need the C<--sudo> option, since
 you're most likely to have a write permission to the perl's library
 path. You can just do:
 
-    curl -L http://cpanmin.us | perl - App::cpanminus
+    curl -L https://cpanmin.us | perl - App::cpanminus
 
 to install the C<cpanm> executable to the perl's bin path, like
 C<~/perl5/perlbrew/bin/cpanm>.
